// Craig S. Kaplan

// Use Spotify's public API to search for albums matching
// a given query string.

import controlP5.*;

// The ControlP5 factory and two UI elements: a text label to tell
// you what mode you're in, and a scrollable text area to show all
// the words found in that mode.
ControlP5 ui;
Textfield field;
Textarea area;

JSONObject albums = null;

void setup()
{
  size( 400, 400 );

  // Set up the user interface
  ui = new ControlP5( this );

  field = ui.addTextfield( "" )
    .setPosition( 5, 5 )
    .setSize( 390, 40 )
    .setFont( createFont( "arial", 24 ) )
    .setColor( color( 255, 255, 255 ) )
    .setAutoClear( false );

  area = ui.addTextarea( "Words" )
    .setPosition( 5, 50 )
    .setSize( 390, 345 )
    .setFont( createFont( "arial", 20 ) )
    .setColor( color( 255, 255, 255 ) );
}

void draw()
{
  background( 50 );
}

void controlEvent( ControlEvent ce )
{
  try {
    if ( ce.isFrom( field ) ) {
      String txt = field.getText();

      // This is a bit messy, but it's just a way to make
      // sure that the query is encoded as a legal URL
      // (in case you include non-ASCII characters, or 
      // spaces, etc.)
      java.net.URI uri = new java.net.URI(
        "https", 
        "api.spotify.com", 
        "/v1/search", 
        "q=" + txt + "&type=album", 
        null );

      // At least, this is the URL we're after
      String request = uri.toASCIIString();

      // Use it to get the live JSON object from the server.
      albums = loadJSONObject( request );
      albums = albums.getJSONObject( "albums" );

      String res = "";

      JSONArray arr = albums.getJSONArray( "items" );
      for ( int idx = 0; idx < arr.size(); ++idx ) {
        JSONObject info = arr.getJSONObject( idx );

        String artist = info.getJSONArray( "artists" ).getJSONObject( 0 ).getString( "name" );
        String title = info.getString( "name" );
        res = res + artist + ": " + title + "\n";
      }

      area.setText( res );
    }
  } 
  catch( Exception e ) {
    println( e );
    e.printStackTrace();
  }
}